# Changelog

## 1.2.4a1 (September 2024)

### Changed
- Update numpy version. [#48]


## 1.2.3 (June 2024)

### Changed
- Fix numpy version.

## 1.2.3a1 (June 2024)

### Fixed
- Fix preprocessing problem with Middleburry datasets. [#29]
- Fix pylint errors due to its update. [#46]


## 1.2.2 (January 2024)

### Changed
- Update of the minimal version for python. [#33]

## 1.2.1 (November 2023)

### Fixed

 - Deletion of the pip install codecov of githubAction CI.
 - Fix pylint error. [#45] 


## 1.2.0 (March 2023)

### Added 

- Suppress xarray dependency, change of API to use numpy array. [#42]
- Add dev dependencies in githubAction file

## 1.1.0 (January 2023)

### Added

 - Add weights submodule to access pretrained weights directly from pip package
 - Add minimal python version 3.7

## 1.0.1 (December 2021)

### Changed

 - Update python packaging.


## 1.0.0 (July 2021)

### Added

- A changelog file.
- Add sphinx documentation.

### Changed

- Readme refactoring.
